@@ -1,9 +1,10 @@
 
-context('Length of the list that is returned by the survglg() function.')
+context("Length of the list that is returned by the survglg() function.")
 
- test_that('test if survglg() returns a list of length 30', {
- expect_length(survglg(Surv(log(obst1), delta1) ~ x1 + x2 - 1, data = example_sglg, shape = 1),
- 30) })
+test_that("test if survglg() returns a list of length 30", {
+    expect_length(survglg(Surv(log(obst1), delta1) ~ x1 + x2 - 1, data = example_sglg, 
+        shape = 1), 30)
+})
 
 context("Messages are returned by the survglg() function.")
 
